--[[ Ask ]]
--[[ My ]]
--[[ math ]]
Position = {}


--[[ Public ]]
function Position.GetPosition(TargetActor, Distance, CoverActor)
	if Distance==nil and CoverActor==nil then
		return GetV(V_POSITION, TargetActor)
		
	else
		if CoverActor==nil then CoverActor=My.ID end
		
		local Radian	= Position.GetRadian(TargetActor, CoverActor)
		
		local CovPos	= { X=0, Y=0 }
		CovPos.X, CovPos.Y = Position.GetPosition(CoverActor)
		
		local HidePos	= {}
		HidePos.Y = math.sin(Radian) * Distance	+ CovPos.Y
		HidePos.X = math.cos(Radian) * Distance	+ CovPos.X
		
		HidePos.Y = math.round(HidePos.Y)
		HidePos.X = math.round(HidePos.X)
		
		return HidePos
	end
end

--[[ Public ]]
function Position.GetOwnerPosition()
	return Position.GetPosition(My.Owner.ID)
end

--[[ Public ]]
function Position.GetMyPosition()
	return Position.GetPosision(My.ID)
end

--[[ Public ]]
function Position.GetDistance(arg1, arg2, arg3, arg4)
	if IsTable(arg1) and IsTable(arg2) then
		return Position.GetDistancePos(arg1.X, arg1.Y, arg2.X, arg2.Y)
		
	elseif not(IsNil(arg1) or IsNil(arg2) or IsNil(arg3) or IsNil(arg4) ) then
		return Position.GetDistancePos(arg1, arg2, arg3, arg4)
		
	elseif not(IsNil(arg1) or IsNil(arg2))  and IsNil(arg3) and IsNil(arg4) then
		return Position.GetDistanceID(arg1, arg2)
		
	else
		assert(arg1)
		assert(arg2)
		assert(arg3)
		assert(arg4)
	end

end

--[[ Public ]]
function Position.GetDistancePos(x1, y1, x2, y2)
	return math.floor( math.sqrt( (x1-x2)^2 + (y1-y2)^2) )
end

--[[ Public ]]
function Position.GetDistanceID(id1, id2)
	local Pos1 = { X=0, Y=0 }
	local Pos2 = { X=0, Y=0 }
	
	Pos1.X, Pos1.Y  = Position.GetPosition(id1)
	Pos2.X, Pos2.Y  = Position.GetPosition(id2)
	
	if (Pos1.X == -1 or Pos2.X == -1) then
		return -1
	end
	
	return Position.GetDistance(Pos1, Pos2)
end

--[[ Public ]]
function Position.GetDistanceFromOwner(ActorID)
	return Position.GetDistance(My.Owner.ID, ActorID)
end

--[[ Public ]]
function Position.GetDistanceFromMe(ActorID)
	return Position.GetDistance(My.ID, ActorID)
end

--[[ Public ]]
function Position.GetNearActorID(ActorIDList, BaseActorID)
	if IsNil(ActorIDList) then
		return false
	end
	
	if IsTable(ActorIDList) and ActorIDList.count==0 then
		return false
	end
	
	local NearActorID	= 0
	local NearDist		= 99999
	local tmp				= 99999
	for i, TargetID in pairs(ActorIDList) do
		if List.IsItem( i ) then
			tmp = Position.GetDistance(BaseActorID, TargetID)
			if tmp < NearDist then
				NearDist		= tmp
				NearActorID	= TargetID
			end
		end
	end
	
	return NearActorID
end

--[[ Public ]]
function Position.GetRadian(BaseID, TargetID)
	local Base		= { X=0, Y=0 }
	local Target	= { X=0, Y=0 }
	
	Base.X, Base.Y		= Position.GetPosition(BaseID)
	Target.X, Target.Y	= Position.GetPosition(TargetID)
	
	Radian = math.radian(Base.X,Base.Y, Target.X,Target.Y)
	
	return Radian
end
